@@ -27,10 +27,10 @@ stan_jm.fit <- function(formulaLong = NULL, dataLong = NULL, formulaEvent = NULL
                         assoc = "etavalue", lag_assoc = 0, grp_assoc, 
                         epsilon = 1E-5, basehaz = c("bs", "weibull", "piecewise"), 
                         basehaz_ops, qnodes = 15, init = "prefit", weights,					          
-                        priorLong = normal(), priorLong_intercept = normal(), 
-                        priorLong_aux = cauchy(0, 5), priorEvent = normal(), 
-                        priorEvent_intercept = normal(), priorEvent_aux = cauchy(),
-                        priorEvent_assoc = normal(), prior_covariance = lkj(), prior_PD = FALSE, 
+                        priorLong = normal(autoscale=TRUE), priorLong_intercept = normal(autoscale=TRUE), 
+                        priorLong_aux = cauchy(0, 5, autoscale=TRUE), priorEvent = normal(autoscale=TRUE), 
+                        priorEvent_intercept = normal(autoscale=TRUE), priorEvent_aux = cauchy(autoscale=TRUE),
+                        priorEvent_assoc = normal(autoscale=TRUE), prior_covariance = lkj(autoscale=TRUE), prior_PD = FALSE, 
                         algorithm = c("sampling", "meanfield", "fullrank"), 
                         adapt_delta = NULL, max_treedepth = 10L, 
                         QR = FALSE, sparse = FALSE, ...) {
